Compute an orthographic view state.

The `size` parameter controls the extends of the projected view. When projecting a 3d world this parameter is expressed in meters. Use the `aspect_ratio` parameter to prevent distortion from induced by non-square viewport.

See [ComputeOrthographicProjectionMatrix], [ComputeAspectRatioX] and [ComputeAspectRatioY].